@@ -712,6 +712,14 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                 }
 
                 FREE(text2);
+
+                string_obj* tmp = STRING_NEW("");
+                saphire_get_quoted_fname(ret, tmp);
+                FREE(ret);
+
+                ret = STRDUP(string_c_str(tmp));
+                string_delete(tmp);
+
                 return ret;
             }
         }
