@@ -31,7 +31,7 @@ static void hash_it_release(hash_it* self)
 ///////////////////////////////////////////////////////////////////////
 // 
 ///////////////////////////////////////////////////////////////////////
-#ifdef MDEBUG
+#if defined(MDEBUG) && !defined(HAVE_GC_H) && !defined(HAVE_GC_GC_H)
 
 hash_obj* hash_new_debug(int size, const char* fname, int line, const char* func_name)
 {
