@@ -2724,7 +2724,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.0.2", 1);
+    setenv("SAPHIRE_VERSION", "3.0.3", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -3579,7 +3579,7 @@ BOOL sWFd_close(sWFd* self)
 BOOL sWFd_push_back(sWFd* self, char* str)
 {
     const int len = strlen(str);
-    const int new_size = (self->mP - self->mBuffer) + len;
+    const int new_size = (self->mP - self->mBuffer) + len + 1;
     if(new_size < self->mMallocSize) {
         while(*str) {
             *(self->mP)++ = *str++;
@@ -3589,10 +3589,11 @@ BOOL sWFd_push_back(sWFd* self, char* str)
     else {
         while(new_size > self->mMallocSize) {
             self->mMallocSize *= 2;
-        }
+       }
 
         char* old_buffer = self->mBuffer;
         self->mBuffer = (char*)MALLOC(self->mMallocSize);
+
         memcpy(self->mBuffer, old_buffer, self->mP - old_buffer);
         self->mP = self->mBuffer + (self->mP - old_buffer);
 
